# mypy-boto3-codedeploy

Mypy-friendly auto-generated type annotations for `boto3 codedeploy 1.10.34` service.
More information can be found [here](https://github.com/vemel/mypy_boto3).

- [mypy-boto3-codedeploy](#mypy-boto3-codedeploy)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `codedeploy` service.

```bash
pip install boto3-stubs[mypy-boto3-codedeploy]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking.

```python
import boto3

from mypy_boto3 import codedeploy
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_codedeploy as codedeploy

# Use this client as usual, now mypy can check if your code is valid.
client: codedeploy.Client = boto3.client("codedeploy")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: codedeploy.Client = session.client("codedeploy")


# Waiters need type annotation on creation
deployment_successful_waiter: codedeploy.DeploymentSuccessfulWaiter = client.get_waiter("deployment_successful")

# Paginators need type annotation on creation
list_application_revisions_paginator: codedeploy.ListApplicationRevisionsPaginator = client.get_paginator("list_application_revisions")
list_applications_paginator: codedeploy.ListApplicationsPaginator = client.get_paginator("list_applications")
list_deployment_configs_paginator: codedeploy.ListDeploymentConfigsPaginator = client.get_paginator("list_deployment_configs")
list_deployment_groups_paginator: codedeploy.ListDeploymentGroupsPaginator = client.get_paginator("list_deployment_groups")
list_deployment_instances_paginator: codedeploy.ListDeploymentInstancesPaginator = client.get_paginator("list_deployment_instances")
list_deployment_targets_paginator: codedeploy.ListDeploymentTargetsPaginator = client.get_paginator("list_deployment_targets")
list_deployments_paginator: codedeploy.ListDeploymentsPaginator = client.get_paginator("list_deployments")
list_git_hub_account_token_names_paginator: codedeploy.ListGitHubAccountTokenNamesPaginator = client.get_paginator("list_git_hub_account_token_names")
list_on_premises_instances_paginator: codedeploy.ListOnPremisesInstancesPaginator = client.get_paginator("list_on_premises_instances")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- Latest version of `boto3` is used.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from latest documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Code is processed by [black](https://github.com/psf/black) for readability.

## Submodules

- `master` - Install `mypy-boto3` package.